==> 0.0.1.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/InitAdSdkManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.ActivityManager;
import android.app.Application;
import android.content.Context;
import android.os.Build;
import android.text.TextUtils;
import android.webkit.WebView;

import androidx.multidex.MultiDex;

import com.yfanads.android.YFAdsConfig;
import com.yfanads.android.YFAdsManager;
import com.yfanads.android.libs.net.UrlConst;
import com.yfanads.android.utils.YFAdsConst;
import com.yifan.yf_ads.bean.InitAdBean;
import com.yifan.yf_ads.utils.FLog;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/24 9:39
 **/
public class InitAdSdkManager {

    private String TAG = "InitAdSdkManager";

    private Context context;
    private boolean hasInitial = false;

    private volatile static InitAdSdkManager initAdSdkManager;

    public static InitAdSdkManager getSingleton() {
        if (initAdSdkManager == null) {  //第一次检查，避免不必要的同步
            synchronized (InitAdSdkManager.class) {  //同步
                if (initAdSdkManager == null) {   //第二次检查，为null时才创建实例
                    initAdSdkManager = new InitAdSdkManager();
                }
            }
        }
        return initAdSdkManager;
    }
    private InitAdSdkManager() {
    }

    public void initSdk(Application application, final InitAdBean initAdBean) {
        try {
            if (hasInitial) {
                FLog.i(TAG, "initSdk hasInitial true");
                return;
            }
            this.context = application.getApplicationContext();
            MultiDex.install(context);
            fixWebView();
            // 一般是在主进程中初始化SDK，避免在其它不展示广告的进程中初始化SDK，浪费资源
            if (TextUtils.equals(context.getPackageName(), getProcessName(context))) {
                initSDK(application, initAdBean);
                hasInitial = true;
            }
            // TODO 测试环境的代码，上线前注释
            UrlConst.setTestEnv();
            YFAdsConst.isUseCache = false;
        } catch (Throwable e) {
            e.printStackTrace();
            hasInitial = false;
        }
    }

    public boolean hasInitial() {
        return hasInitial;
    }

    /**
     * 在Android 9开始不允许同一个应用的多个进程中使用WebView，否则会出现Crash。
     * 通过改方法规避。
     */
    private void fixWebView() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            String processName = getProcessName(context);
            String packageName = context.getPackageName();
            String suffix = packageName + android.os.Process.myPid();
            if (!TextUtils.isEmpty(processName)) {
                suffix = processName;
            }
            if (!packageName.equals(processName)) {
                try {
                    WebView.setDataDirectorySuffix(suffix);
                } catch (Throwable e) {
                    e.printStackTrace();
                }
            } else {
                try {
                    WebView.setDataDirectorySuffix(packageName);
                } catch (Exception unused) {
                }
            }
        }
    }

    private String getProcessName(Context context) {
        if (context == null) return null;
        ActivityManager manager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        for (ActivityManager.RunningAppProcessInfo processInfo : manager.getRunningAppProcesses()) {
            if (processInfo.pid == android.os.Process.myPid()) {
                return processInfo.processName;
            }
        }
        return null;
    }

    private void initSDK(Application application, final InitAdBean initAdBean) {
        // 初始化SDK
        YFAdsConfig fcAdsConfig =
                new YFAdsConfig.YFAdsConfigBuilder(initAdBean.getAppId())
                        // debug调试阶段的日志，正式包请注释
                        .setDebug(initAdBean.isEnableLog())
                        .builder();
        fcAdsConfig.setCanUsePhoneState(initAdBean.isPermissionPhoneState());
        fcAdsConfig.setCanUseAndroidId(initAdBean.isPermissionAndroidId());
        fcAdsConfig.setCanUseLocation(initAdBean.isPermissionLocation());
        fcAdsConfig.setCanUseWriteExternal(initAdBean.isPermissionWriteExternal());
        fcAdsConfig.setCanUseWifiState(initAdBean.isPermissionWifiState());
        fcAdsConfig.setCanUseAppList(initAdBean.isPermissionAppList());
        fcAdsConfig.setCanUseOaid(initAdBean.isPermissionOaid());
        fcAdsConfig.setDevImei(initAdBean.getImei());
        fcAdsConfig.setDevOaid(initAdBean.getOaid());
        YFAdsManager.getInstance().init(application, fcAdsConfig);
    }
}

==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/InitAdSdkManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.ActivityManager;
import android.app.Application;
import android.content.Context;
import android.os.Build;
import android.text.TextUtils;
import android.webkit.WebView;

import androidx.multidex.MultiDex;

import com.yfanads.android.YFAdsConfig;
import com.yfanads.android.YFAdsManager;
import com.yfanads.android.libs.net.UrlConst;
import com.yfanads.android.utils.YFAdsConst;
import com.yifan.yf_ads.bean.InitAdBean;
import com.yifan.yf_ads.utils.FLog;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/24 9:39
 **/
public class InitAdSdkManager {

    private String TAG = "InitAdSdkManager";

    private Context context;
    private boolean hasInitial = false;

    private volatile static InitAdSdkManager initAdSdkManager;

    public static InitAdSdkManager getSingleton() {
        if (initAdSdkManager == null) {  //第一次检查，避免不必要的同步
            synchronized (InitAdSdkManager.class) {  //同步
                if (initAdSdkManager == null) {   //第二次检查，为null时才创建实例
                    initAdSdkManager = new InitAdSdkManager();
                }
            }
        }
        return initAdSdkManager;
    }
    private InitAdSdkManager() {
    }

    public void initSdk(Application application, final InitAdBean initAdBean) {
        try {
            if (hasInitial) {
                FLog.i(TAG, "initSdk hasInitial true");
                return;
            }
            this.context = application.getApplicationContext();
            MultiDex.install(context);
            fixWebView();
            // 一般是在主进程中初始化SDK，避免在其它不展示广告的进程中初始化SDK，浪费资源
            if (TextUtils.equals(context.getPackageName(), getProcessName(context))) {
                initSDK(application, initAdBean);
                hasInitial = true;
            }
            // 测试环境的代码，上线前注释
//            UrlConst.setTestEnv();
//            YFAdsConst.isUseCache = false;
        } catch (Throwable e) {
            e.printStackTrace();
            hasInitial = false;
        }
    }

    public boolean hasInitial() {
        return hasInitial;
    }

    /**
     * 在Android 9开始不允许同一个应用的多个进程中使用WebView，否则会出现Crash。
     * 通过改方法规避。
     */
    private void fixWebView() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            String processName = getProcessName(context);
            String packageName = context.getPackageName();
            String suffix = packageName + android.os.Process.myPid();
            if (!TextUtils.isEmpty(processName)) {
                suffix = processName;
            }
            if (!packageName.equals(processName)) {
                try {
                    WebView.setDataDirectorySuffix(suffix);
                } catch (Throwable e) {
                    e.printStackTrace();
                }
            } else {
                try {
                    WebView.setDataDirectorySuffix(packageName);
                } catch (Exception unused) {
                }
            }
        }
    }

    private String getProcessName(Context context) {
        if (context == null) return null;
        ActivityManager manager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        for (ActivityManager.RunningAppProcessInfo processInfo : manager.getRunningAppProcesses()) {
            if (processInfo.pid == android.os.Process.myPid()) {
                return processInfo.processName;
            }
        }
        return null;
    }

    private void initSDK(Application application, final InitAdBean initAdBean) {
        // 初始化SDK
        YFAdsConfig fcAdsConfig =
                new YFAdsConfig.YFAdsConfigBuilder(initAdBean.getAppId())
                        // debug调试阶段的日志，正式包请注释
                        .setDebug(initAdBean.isEnableLog())
                        .builder();
        fcAdsConfig.setCanUsePhoneState(initAdBean.isPermissionPhoneState());
        fcAdsConfig.setCanUseAndroidId(initAdBean.isPermissionAndroidId());
        fcAdsConfig.setCanUseLocation(initAdBean.isPermissionLocation());
        fcAdsConfig.setCanUseWriteExternal(initAdBean.isPermissionWriteExternal());
        fcAdsConfig.setCanUseWifiState(initAdBean.isPermissionWifiState());
        fcAdsConfig.setCanUseAppList(initAdBean.isPermissionAppList());
        fcAdsConfig.setCanUseOaid(initAdBean.isPermissionOaid());
        fcAdsConfig.setDevImei(initAdBean.getImei());
        fcAdsConfig.setDevOaid(initAdBean.getOaid());
        YFAdsManager.getInstance().init(application, fcAdsConfig);
    }
}
